#ifndef INCLUDE_DICTIONARY_H
#define INCLUDE_DICTIONARY_H

#include <hildon/hildon-program.h>
#include <gtk/gtk.h>

#define BULLSHIT_BINGO_STORE_FILE ".bullshitbingo/dictionary"

void  dict_prepare();
gint  dict_size();
void  dict_add(gchar*);
void  dict_remove(gchar*);
gchar *dict_get_mixed(int);
gchar *dict_get(int);
void  dict_mix();
void  dict_order();
gboolean dict_exists(gchar*);
void dict_load_from_file();
void dict_save_to_file();
gint compare_strings(gconstpointer, gconstpointer);

#endif
/* ifndef INCLUDE_DICTIONARY_H */

